@@ -46,13 +46,6 @@ G_BEGIN_DECLS
 typedef struct _GAppLaunchContextClass   GAppLaunchContextClass;
 typedef struct _GAppLaunchContextPrivate GAppLaunchContextPrivate;
 
-/**
- * GAppInfo:
- *
- * Information about an installed application and methods to launch
- * it (with file arguments).
- */
-
 /**
  * GAppInfoIface:
  * @g_iface: The parent interface.
@@ -146,139 +139,139 @@ struct _GAppInfoIface
                                                  GError            **error);
 };
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GType       g_app_info_get_type                     (void) G_GNUC_CONST;
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GAppInfo *  g_app_info_create_from_commandline      (const char           *commandline,
                                                      const char           *application_name,
                                                      GAppInfoCreateFlags   flags,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GAppInfo *  g_app_info_dup                          (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_equal                        (GAppInfo             *appinfo1,
                                                      GAppInfo             *appinfo2);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 const char *g_app_info_get_id                       (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 const char *g_app_info_get_name                     (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 const char *g_app_info_get_display_name             (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 const char *g_app_info_get_description              (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 const char *g_app_info_get_executable               (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 const char *g_app_info_get_commandline              (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GIcon *     g_app_info_get_icon                     (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_launch                       (GAppInfo             *appinfo,
                                                      GList                *files,
                                                      GAppLaunchContext    *context,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_supports_uris                (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_supports_files               (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_launch_uris                  (GAppInfo             *appinfo,
                                                      GList                *uris,
                                                      GAppLaunchContext    *context,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_2_60
+GIO_AVAILABLE_IN_2_60
 void        g_app_info_launch_uris_async            (GAppInfo             *appinfo,
                                                      GList                *uris,
                                                      GAppLaunchContext    *context,
                                                      GCancellable         *cancellable,
                                                      GAsyncReadyCallback   callback,
                                                      gpointer              user_data);
-GLIB_AVAILABLE_IN_2_60
+GIO_AVAILABLE_IN_2_60
 gboolean    g_app_info_launch_uris_finish           (GAppInfo             *appinfo,
                                                      GAsyncResult         *result,
                                                      GError              **error);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_should_show                  (GAppInfo             *appinfo);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_set_as_default_for_type      (GAppInfo             *appinfo,
                                                      const char           *content_type,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_set_as_default_for_extension (GAppInfo             *appinfo,
                                                      const char           *extension,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_add_supports_type            (GAppInfo             *appinfo,
                                                      const char           *content_type,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_can_remove_supports_type     (GAppInfo             *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_remove_supports_type         (GAppInfo             *appinfo,
                                                      const char           *content_type,
                                                      GError              **error);
-GLIB_AVAILABLE_IN_2_34
+GIO_AVAILABLE_IN_2_34
 const char **g_app_info_get_supported_types         (GAppInfo             *appinfo);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_can_delete                   (GAppInfo   *appinfo);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_delete                       (GAppInfo   *appinfo);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean    g_app_info_set_as_last_used_for_type    (GAppInfo             *appinfo,
                                                      const char           *content_type,
                                                      GError              **error);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GList *   g_app_info_get_all                     (void);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GList *   g_app_info_get_all_for_type            (const char  *content_type);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GList *   g_app_info_get_recommended_for_type    (const gchar *content_type);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GList *   g_app_info_get_fallback_for_type       (const gchar *content_type);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 void      g_app_info_reset_type_associations     (const char  *content_type);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GAppInfo *g_app_info_get_default_for_type        (const char  *content_type,
                                                   gboolean     must_support_uris);
-GLIB_AVAILABLE_IN_2_74
+GIO_AVAILABLE_IN_2_74
 void      g_app_info_get_default_for_type_async  (const char          *content_type,
                                                   gboolean             must_support_uris,
                                                   GCancellable        *cancellable,
                                                   GAsyncReadyCallback  callback,
                                                   gpointer             user_data);
-GLIB_AVAILABLE_IN_2_74
+GIO_AVAILABLE_IN_2_74
 GAppInfo *g_app_info_get_default_for_type_finish (GAsyncResult         *result,
                                                   GError              **error);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GAppInfo *g_app_info_get_default_for_uri_scheme  (const char  *uri_scheme);
 
-GLIB_AVAILABLE_IN_2_74
+GIO_AVAILABLE_IN_2_74
 void      g_app_info_get_default_for_uri_scheme_async (const char          *uri_scheme,
                                                        GCancellable        *cancellable,
                                                        GAsyncReadyCallback  callback,
                                                        gpointer             user_data);
-GLIB_AVAILABLE_IN_2_74
+GIO_AVAILABLE_IN_2_74
 GAppInfo *g_app_info_get_default_for_uri_scheme_finish (GAsyncResult         *result,
                                                         GError              **error);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 gboolean  g_app_info_launch_default_for_uri      (const char              *uri,
                                                   GAppLaunchContext       *context,
                                                   GError                 **error);
 
-GLIB_AVAILABLE_IN_2_50
+GIO_AVAILABLE_IN_2_50
 void      g_app_info_launch_default_for_uri_async  (const char           *uri,
                                                     GAppLaunchContext    *context,
                                                     GCancellable         *cancellable,
                                                     GAsyncReadyCallback   callback,
                                                     gpointer              user_data);
-GLIB_AVAILABLE_IN_2_50
+GIO_AVAILABLE_IN_2_50
 gboolean  g_app_info_launch_default_for_uri_finish (GAsyncResult         *result,
                                                     GError              **error);
 
@@ -323,30 +316,30 @@ struct _GAppLaunchContextClass
   void (*_g_reserved3) (void);
 };
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GType              g_app_launch_context_get_type              (void) G_GNUC_CONST;
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 GAppLaunchContext *g_app_launch_context_new                   (void);
 
-GLIB_AVAILABLE_IN_2_32
+GIO_AVAILABLE_IN_2_32
 void               g_app_launch_context_setenv                (GAppLaunchContext *context,
                                                                const char        *variable,
                                                                const char        *value);
-GLIB_AVAILABLE_IN_2_32
+GIO_AVAILABLE_IN_2_32
 void               g_app_launch_context_unsetenv              (GAppLaunchContext *context,
                                                                const char        *variable);
-GLIB_AVAILABLE_IN_2_32
+GIO_AVAILABLE_IN_2_32
 char **            g_app_launch_context_get_environment       (GAppLaunchContext *context);
 
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 char *             g_app_launch_context_get_display           (GAppLaunchContext *context,
                                                                GAppInfo          *info,
                                                                GList             *files);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 char *             g_app_launch_context_get_startup_notify_id (GAppLaunchContext *context,
                                                                GAppInfo          *info,
                                                                GList             *files);
-GLIB_AVAILABLE_IN_ALL
+GIO_AVAILABLE_IN_ALL
 void               g_app_launch_context_launch_failed         (GAppLaunchContext *context,
                                                                const char *       startup_notify_id);
 
@@ -358,10 +351,10 @@ void               g_app_launch_context_launch_failed         (GAppLaunchContext
 
 typedef struct _GAppInfoMonitor                             GAppInfoMonitor;
 
-GLIB_AVAILABLE_IN_2_40
+GIO_AVAILABLE_IN_2_40
 GType                   g_app_info_monitor_get_type                     (void);
 
-GLIB_AVAILABLE_IN_2_40
+GIO_AVAILABLE_IN_2_40
 GAppInfoMonitor *       g_app_info_monitor_get                          (void);
 
 G_END_DECLS
